@@ -18,6 +18,7 @@
 #include <kstartupinfo.h>
 #include <kwin.h>
 #include <kwinmodule.h>
+#include <kiconloader.h>
 
 #include "amor.h"
 #include "amor.moc"
@@ -27,6 +28,7 @@
 #include "amordialog.h"
 #include "version.h"
 #include <X11/Xlib.h>
+#include <kdebug.h>
 
 #define SLEEP_TIMEOUT   180     // Animation sleeps after SLEEP_TIMEOUT seconds
                                 // of mouse inactivity.
@@ -47,11 +49,11 @@
 //
 // Constructor
 //
-Amor::Amor() : QObject(), DCOPObject( "AmorIface" )
+Amor::Amor() : DCOPObject( "AmorIface" ), QObject()
 {
     mAmor = 0;
     mBubble = 0;
-
+    mForceHideAmorWidget = false;
     if (readConfig())
     {
         mTargetWin   = 0;
@@ -99,6 +101,15 @@ Amor::Amor() : QObject(), DCOPObject( "AmorIface" )
             selectAnimation(Focus);
             mTimer->start(0, true);
         }
+	if (!connectDCOPSignal(0,0, "KDE_stop_screensaver()", "screenSaverStopped()",false))
+		kdDebug(10000) << "Could not attach signal...KDE_stop_screensaver()" << endl;
+	else
+		kdDebug(10000) << "attached dcop signals..." << endl;
+
+	if (!connectDCOPSignal(0,0, "KDE_start_screensaver()", "screenSaverStarted()",false))
+		kdDebug(10000) << "Could not attach signal...KDE_start_screensaver()" << endl;
+	else
+		kdDebug(10000) << "attached dcop signals..." << endl;
 
         KStartupInfo::appStarted();
     }
@@ -119,6 +130,21 @@ Amor::~Amor()
     delete mBubble;
 }
 
+void Amor::screenSaverStopped()
+{
+    kdDebug(10000)<<"void Amor::screenSaverStopped() \n";
+    mAmor->show();
+    mForceHideAmorWidget = false;
+}
+
+void Amor::screenSaverStarted()
+{
+    kdDebug(10000)<<"void Amor::screenSaverStarted() \n";
+    mAmor->hide();
+    mTimer->stop();
+    mForceHideAmorWidget = true;
+}
+
 //---------------------------------------------------------------------------
 //
 void Amor::showTip( QString tip )
@@ -153,6 +179,7 @@ void Amor::reset()
     mState      = Normal;
 
     mAmor = new AmorWidget();
+    mForceHideAmorWidget = false;
     connect(mAmor, SIGNAL(mouseClicked(const QPoint &)),
                     SLOT(slotMouseClicked(const QPoint &)));
     connect(mAmor, SIGNAL(dragged(const QPoint &, bool)),
@@ -264,7 +291,7 @@ void Amor::selectAnimation(State state)
             mTargetWin = mNextTarget;
             if (mTargetWin != None)
             {
-                mTargetRect = KWin::info(mTargetWin).frameGeometry;
+                mTargetRect = KWin::windowInfo(mTargetWin).frameGeometry();
 		if ( mTheme.isStatic() )
 		{
 		    if ( mConfig.mStaticPos < 0 )
@@ -415,10 +442,10 @@ void Amor::slotMouseClicked(const QPoint &pos)
     {
         mMenu = new KPopupMenu();
 	mMenu->insertTitle("Amor"); // I really don't want this i18n'ed
-        mMenu->insertItem(i18n("&Options..."), this, SLOT(slotConfigure()));
+        mMenu->insertItem(SmallIcon("configure"),i18n("&Options..."), this, SLOT(slotConfigure()));
         mMenu->insertItem(i18n("&About"), this, SLOT(slotAbout()));
         mMenu->insertSeparator();
-        mMenu->insertItem(i18n("&Quit"), kapp, SLOT(quit()));
+        mMenu->insertItem(SmallIcon("exit"),i18n("&Quit"), kapp, SLOT(quit()));
     }
 
     mMenu->exec(pos);
@@ -462,6 +489,8 @@ void Amor::slotCursorTimeout()
 //
 void Amor::slotTimeout()
 {
+    if ( mForceHideAmorWidget )
+        return;
     if (!mTheme.isStatic())
 	mPosition += mCurrAnim->movement();
     mAmor->setPixmap(mCurrAnim->frame());
@@ -490,7 +519,7 @@ void Amor::slotTimeout()
     }
 
     if (mTheme.isStatic())
-	mTimer->start(mState == Normal ? 10000 : 0, true);
+	mTimer->start(((mState == Normal) || (mState == Sleeping)) ? 10000 : 100, true);
     else
 	mTimer->start(mCurrAnim->delay(), true);
 
