@@ -5,8 +5,8 @@
 // Copyright (c) 1999 Martin R. Jones <mjones@kde.org>
 //
 
-#include <amorbubble.h>
-#include <amorbubble.moc>
+#include "amorbubble.h"
+#include "amorbubble.moc"
 #include <qpainter.h>
 #include <ktextbrowser.h>
 #include <qtooltip.h>
@@ -114,6 +114,10 @@ void AmorBubble::calcGeometry()
         mArrowVert = Bottom;
     }
 
+    // Check for negative vertical bubble position (top of the screen)
+    if ( ypos < 0 )
+       ypos = 0;
+
     setGeometry(xpos, ypos, w, h);
     mBrowser->setGeometry( mBound );
 
