@@ -18,7 +18,7 @@
 #include "amor.h"
 
 
-static const char *description = I18N_NOOP("KDE creature for your desktop.");
+static const char description[] = I18N_NOOP("KDE creature for your desktop.");
 
 int main(int argc, char *argv[])
 {
