@@ -14,7 +14,7 @@
  *
  *   You should have received a copy of the GNU General Public License
  *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
+ *   Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
  *
  */
 
@@ -41,8 +41,8 @@ KMoonDlg::KMoonDlg(int _angle, bool n, QWidget *parent, const char *name)
         hbox->setSpacing(15);
 
 	QLabel *label = new QLabel( i18n("View angle:"), hbox, "caption" );
-	QString text = i18n("This rotates the moon to the correct\n"
-                            "angle, as viewed from the equator.\n"
+	QString text = i18n("You can use this to rotate the moon to the correct\n"
+                            "angle for your location.\n"
 			    "\n"
                             "This angle is (almost) impossible to\n"
                             "calculate from any system-given data,\n"
