@@ -18,26 +18,15 @@
 #ifndef KWEATHER_H
 #define KWEATHER_H
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <kapplication.h>
-#include <qwidget.h>
 #include <kpanelapplet.h>
-#include <qtimer.h>
-#include <dockwidget.h>
-#include <kio/job.h>
-#include <klocale.h>
-#include <qpixmap.h>
-#include <qfont.h>
-#include <dcopclient.h>
+#include <dcopref.h>
 
-#include "prefsDialog.h"
-#include "reportview.h"
 #include "weatherIface.h"
 
-class prefsDialog;
+class QTimer;
+class dockwidget;
+class reportView;
+class KPopupMenu;
 
 class kweather : public KPanelApplet, public weatherIface
 {
@@ -47,6 +36,7 @@ public:
 	kweather(const QString& configFile, Type t = Normal, int actions = 0, QWidget *parent = 0, const char *name = 0);
 	~kweather();
 	void help();
+	void resizeEvent(QResizeEvent*);
 	int heightForWidth(int i) const;
 	int widthForHeight(int i) const;
 	void refresh(QString);
@@ -54,54 +44,38 @@ public:
 public slots: // Public slots
 	void preferences();
 	void about();
-	void getButtonEvent();
+
+protected slots:
 	void doReport();
 	void timeout();
 	void slotPrefsAccepted();
-	void slotPrefsFinished();
 	void slotReportFinished();
+	void slotUpdateNow();
 
 private: // Private methods
+	void initContextMenu();
+	void initDCOP();
 	void loadPrefs();
 	void savePrefs();
 	void showWeather();
 	void writeLogEntry();
-	void mousePressEvent(QMouseEvent * ev);
-	
-	// DCOP service wrapper
-	QString temperature(QString stationID);
-	QString dewPoint(QString stationID);
-	QString relHumidity(QString stationID);
-	QString heatIndex(QString stationID);
-	QString windChill(QString stationID);
-	QString wind(QString stationID);
-	QString pressure(QString stationID);
-	QPixmap currentIcon(QString stationID);
-	QString currentIconString(QString stationID);
-	QString date(QString stationID);
-	QStringList weather(QString stationID);
-	QString visibility(QString stationID);
-	QStringList cover(QString stationID);
-	void update(QString stationID);
+	void mousePressEvent(QMouseEvent *e);
+	DCOPReply callDCOP( const QString &name );
+
 	bool attach();
-		
+
 	QString reportLocation;
-	int interval;
 	QString fileName;
-	bool logOn;
-	bool firstrun;
-	bool offlineMode;
-	bool smallviewMode;
-	QTimer *timeOut;
-	QFont theFont;
-	int status;
-	dockwidget *p;
-	reportView *theView;
-	KIO::TransferJob *theJob;
 	QString metarData;
-	prefsDialog *mPrefs;
+	bool logOn;
+	bool mFirstRun;
+	int mViewMode;
+	QTimer *timeOut;
+	dockwidget *p;
 	reportView *mReport;
-	DCOPClient *client;
+	DCOPClient *mClient;
+	DCOPRef *mWeatherService;
+	KPopupMenu *mContextMenu;
 };
 
 #endif
