@@ -21,7 +21,10 @@
 #include <kdialogbase.h>
 #include <qstringlist.h>
 
+#include <dcopref.h>
+
 class KHTMLPart;
+class DCOPRef;
 
 /**This is the main report generated for the user.
   *@author Ian Reinhart Geiser
@@ -33,36 +36,32 @@ class reportView : public KDialogBase {
 public:
     reportView(QString reportLocation);
     ~reportView();
-    
+
+    void getWeatherData();
     void render();
-    void setLocation( QString location );
-    void setTemp( QString temp );
-    void setDewPoint( QString dewpoint );
-    void setRelHumidity( QString relhumidity );
-    void setHeatIndex( QString heatIndex );
-    void setWindChill( QString windchill );
-    void setWind( QString wind );
-    void setDate( QString date );
-    void setPressure( QString pressure );
-    void setCover( QStringList cover );
-    void setWeather( QStringList weather );
-    void setWeatherIcon( const QString &icon );
+
+protected:
+    DCOPReply callDCOP( const QString &name );
 
 private:
-    KHTMLPart *theReport;
-    QString locationCode;
-    QString currentTemp;
-    QString currentDewPoint;
-    QString currentRelHumidity;
-    QString currentHeatIndex;
-    QString currentWindChill;
-    QString currentTime;
-    QString currentPressure;
-    QString currentWind;
-    QString currentDate;
-    QStringList currentCover;
-    QStringList currentWeather;
-    QString currentIcon;
+    DCOPRef *m_weatherService;
+    KHTMLPart *m_reportView;
+    QString m_locationCode;
+    QString m_locationName;
+    QString m_temp;
+    QString m_dewPoint;
+    QString m_relHumidity;
+    QString m_heatIndex;
+    QString m_windChill;
+    QString m_time;
+    QString m_pressure;
+    QString m_wind;
+    QString m_sunRiseTime;
+    QString m_sunSetTime;
+    QString m_date;
+    QString m_icon;
+    QStringList m_cover;
+    QStringList m_weather;
 };
 
 #endif
