@@ -31,6 +31,8 @@ email                : geiseri@msoe.edu
 #include <unistd.h>
 #include <kapplication.h>
 #include <kpassivepopup.h>
+#include "stationdatabase.h"
+#include "sun.h"
 #include "weatherlib.h"
 
 #include "weatherlib.moc"
@@ -38,34 +40,8 @@ email                : geiseri@msoe.edu
 class WeatherLib::Data
 {
 	public:
-		Data()
-		{
-			theWeather = QString::null;
-			clouds = -1;
-			windMPH = 0;
-			tempF = 0;
-			heavy = false;
-			qsCoverList.clear();
-			qsCurrentList.clear();
-			qsDate = QDate::currentDate();
-			qsPressure = QString::null;
-			qsTemperature = QString::null;
-			qsDewPoint = QString::null;
-			qsRelHumidity = QString::null;
-			qsTime = QTime::currentTime();
-			qsVisibility = QString::null;
-			qsWindSpeed = QString::null;
-			qsWindChill = QString::null;
-			qsHeatIndex = QString::null;
-			qsWindDirection = QString::null;
-			reportLocation = QString::null;
-			age = QDateTime::currentDateTime();
-			target = 0L;
-			downloading = false;
-			updated = false;
-			job = 0L;
-		};
-		~Data(){};
+		Data();
+		~Data(){ if ( target ) delete target; }
 
 		void clear();
 
@@ -96,35 +72,51 @@ class WeatherLib::Data
 		KIO::Job *job;
 };
 
+WeatherLib::Data::Data()
+		: target( 0 ), job( 0 )
+{
+	clear();
+}
+
 void WeatherLib::Data::clear()
 {
-	theWeather = "";
-	clouds = 0;
+	theWeather = QString::null;
+	clouds = -1;
 	windMPH = 0;
 	tempF = 0;
+	heavy = false;
 	qsCoverList.clear();
 	qsCurrentList.clear();
 	qsDate = QDate::currentDate();
-	qsPressure = "";
-	qsTemperature = "";
-	qsDewPoint = "";
-	qsRelHumidity = "";
 	qsTime = QTime::currentTime();
-	qsVisibility = "";
-	qsWindSpeed = "";
-	qsWindChill = "";
-	qsHeatIndex = "";
-	qsWindDirection = "";
+	qsPressure = QString::null;
+	qsTemperature = QString::null;
+	qsDewPoint = QString::null;
+	qsRelHumidity = QString::null;
+	qsVisibility = QString::null;
+	qsWindSpeed = QString::null;
+	qsWindChill = QString::null;
+	qsHeatIndex = QString::null;
+	qsWindDirection = QString::null;
 	age = QDateTime::currentDateTime();
-	target = 0L;
 	downloading = false;
 	updated = false;
-	job = 0L;
+	job = 0;
+
+	if ( target )
+	{
+		delete target;
+		target = 0;
+	}
 }
 
-WeatherLib::WeatherLib(QObject *parent, const char *name)
+WeatherLib::WeatherLib(StationDatabase *stationDB, QObject *parent, const char *name)
 	: QObject (parent, name)
 {
+	KGlobal::locale()->insertCatalogue("kweather");
+	
+	m_StationDb    = stationDB;
+	
 	CoverRegExp    = QRegExp("^(FEW|SCT|BKN|OVC|SKC|CLR|CAVOK)([0-9]{3})?(?:TCU|CB)?$");
 	CurrentRegExp  = QRegExp("^(\\+|-|VC)?([A-Z]{2,4})$");
 	WindRegExp     = QRegExp("^([0-9]{3}|VRB)([0-9]{2,3})(?:G([0-9]{2,3}))?(KT|KMH|MPS)$");
@@ -134,6 +126,8 @@ WeatherLib::WeatherLib(QObject *parent, const char *name)
 	TimeRegExp     = QRegExp("^([0-9]{2}:[0-9]{2})$");
 	DateRegExp     = QRegExp("^([0-9]{4}/[0-9]{2}/[0-9]{2})$");
 	PressRegExp    = QRegExp("^([AQ])([0-9]{4})$");
+
+	data.setAutoDelete( true );
 }
 
 WeatherLib::~WeatherLib()
@@ -141,10 +135,10 @@ WeatherLib::~WeatherLib()
 }
 
 /** Parse the current cover type */
-bool WeatherLib::parseCover(QString s, Data *d){
+bool WeatherLib::parseCover(const QString &s, Data *d){
 	if (CoverRegExp.search(s) > -1)
 	{
-		kdDebug(12004) << "Cover: " << CoverRegExp.capturedTexts().join("-")
+		kdDebug(12006) << "Cover: " << CoverRegExp.capturedTexts().join("-")
 			<< endl;
 
 		QString sCode = CoverRegExp.cap(1);
@@ -200,7 +194,7 @@ bool WeatherLib::parseCover(QString s, Data *d){
 			d->clouds = 0;
 		}
 
-		kdDebug(12004) << "*** Clouds: " << d->clouds << endl;
+		kdDebug(12006) << "*** Clouds: " << d->clouds << endl;
 		d->qsCoverList << skycondition;
 
 		return true;
@@ -209,14 +203,14 @@ bool WeatherLib::parseCover(QString s, Data *d){
 }
 
 /** Parse the current weather conditions */
-bool WeatherLib::parseCurrent(QString s, Data *d){
+bool WeatherLib::parseCurrent(const QString &s, Data *d){
 	if (CurrentRegExp.search(s) > -1)
 	{
 		QString sIntensity = CurrentRegExp.cap(1);
 		QString sCode = CurrentRegExp.cap(2);
 		QString currentWeather = "";
 
-		kdDebug(12004) << "Current: " << CurrentRegExp.capturedTexts().join("-") << endl;
+		kdDebug(12006) << "Current: " << CurrentRegExp.capturedTexts().join("-") << endl;
 
 		// Decode the intensity
 		if (sIntensity == "+")
@@ -300,25 +294,25 @@ bool WeatherLib::parseCurrent(QString s, Data *d){
 		else if (s.contains("UP"))
 		{
 			currentWeather += i18n(" Unknown Precipitation");
-			d->theWeather = "shower1";
+			d->theWeather = iconName("shower1", d);
 		}
 		else if (sCode.contains("BR"))
 		{
 			currentWeather += i18n(" Mist");
-                       // Mist has lower priority than say rain or snow
-                       if ( d->theWeather.isEmpty() )
-                       {
-                               d->theWeather = "mist";
-                       }
+			// Mist has lower priority than say rain or snow
+			if ( d->theWeather.isEmpty() )
+			{
+				d->theWeather = "mist";
+			}
 		}
 		else if (sCode.contains("FG"))
 		{
 			currentWeather += i18n(" Fog");
-                       // Fog has lower priority than say rain or snow
-                       if ( d->theWeather.isEmpty() )
-                       {
-                               d->theWeather = "fog";
-                       }
+			// Fog has lower priority than say rain or snow
+			if ( d->theWeather.isEmpty() )
+			{
+				d->theWeather = "fog";
+			}
 		}
 		else if (sCode.contains("FU"))
 			currentWeather += i18n(" Smoke");
@@ -349,26 +343,26 @@ bool WeatherLib::parseCurrent(QString s, Data *d){
 			currentWeather += i18n("Dust Storm");
 
 		if (!currentWeather.isEmpty())
-		d->qsCurrentList << currentWeather;
+			d->qsCurrentList << currentWeather;
 
 		return true;
-		}
+	}
 	return false;
 }
 
 /** Parse out the current temperature */
-bool WeatherLib::parseTemperature(QString s, Data *d){
+bool WeatherLib::parseTemperature(const QString &s, Data *d){
 	if (TempRegExp.search(s) > -1)
 	{
 		QString unit;
-		kdDebug(12004) << "Temp: " << TempRegExp.capturedTexts().join("-")
+		kdDebug(12006) << "Temp: " << TempRegExp.capturedTexts().join("-")
 			<< endl;
 
 		float fTemp = TempRegExp.cap(2).toFloat();
-		if (TempRegExp.cap(1) == "M")
+		if (TempRegExp.cap(1) == "M" && fTemp != 0 )
 			fTemp *= -1;
 		float fDew = TempRegExp.cap(4).toFloat();
-		if (TempRegExp.cap(3) == "M")
+		if (TempRegExp.cap(3) == "M" && fDew != 0 )
 			fDew *= -1;
 
 		#define E(t) ::pow(10, 7.5*t/(237.7+t))
@@ -421,10 +415,10 @@ bool WeatherLib::parseTemperature(QString s, Data *d){
 }
 
 /** Parse out the current date. */
-bool WeatherLib::parseDate(QString s, Data *d){
+bool WeatherLib::parseDate(const QString &s, Data *d){
 	if (DateRegExp.search(s) > -1)
 	{
-		kdDebug(12004) << "Date: " << DateRegExp.capturedTexts().join("-")
+		kdDebug(12006) << "Date: " << DateRegExp.capturedTexts().join("-")
 			<< endl;
 		QString dateString = DateRegExp.cap(1);
 		QString day, month, year;
@@ -443,10 +437,10 @@ bool WeatherLib::parseDate(QString s, Data *d){
 }
 
 /** Parse out the current time. */
-bool WeatherLib::parseTime(QString s, Data *d){
+bool WeatherLib::parseTime(const QString &s, Data *d){
 	if (TimeRegExp.search(s) > -1)
 	{
-		kdDebug(12004) << "Time: " << TimeRegExp.capturedTexts().join("-")
+		kdDebug(12006) << "Time: " << TimeRegExp.capturedTexts().join("-")
 			<< endl;
 
 		QString hour, minute, dateString;
@@ -463,12 +457,12 @@ bool WeatherLib::parseTime(QString s, Data *d){
 }
 
 /** Parse out the current visibility */
-bool WeatherLib::parseVisibility( QString s, Data *d){
+bool WeatherLib::parseVisibility( const QString &s, Data *d){
 	if (VisRegExp.search(s) > -1)
 	{
 		float fVisibility = VisRegExp.cap(1).toFloat();
 
-		kdDebug(12004) << "Visibility: " << VisRegExp.capturedTexts().join("-")
+		kdDebug(12006) << "Visibility: " << VisRegExp.capturedTexts().join("-")
 			<< endl;
 
 		if (KGlobal::locale()->measureSystem() == KLocale::Metric)
@@ -488,13 +482,13 @@ bool WeatherLib::parseVisibility( QString s, Data *d){
 }
 
 /** Parse out the current pressure. */
-bool WeatherLib::parsePressure( QString s, Data *d){
+bool WeatherLib::parsePressure( const QString &s, Data *d){
 	if (PressRegExp.search(s) > -1)
 	{
 		QString type = PressRegExp.cap(1);
 		float fPressure = PressRegExp.cap(2).toFloat();
 
-		kdDebug(12004) << "Pressure: " << PressRegExp.capturedTexts().join("-")
+		kdDebug(12006) << "Pressure: " << PressRegExp.capturedTexts().join("-")
 			<< endl;
 
 		if (KGlobal::locale()->measureSystem() == KLocale::Metric)
@@ -518,17 +512,62 @@ bool WeatherLib::parsePressure( QString s, Data *d){
 	return false;
 }
 
+struct WeatherLib::wind_info
+{
+	unsigned int   number;
+	QString        name;
+};
+
+const struct WeatherLib::wind_info WeatherLib::wind_direction[] = 
+{
+	{ 0,   i18n("N")   },   // North is 0 to 11, and so on
+	{ 12,  i18n("NNE") },
+	{ 33,  i18n("NE")  },
+	{ 57,  i18n("ENE") },
+	{ 79,  i18n("E")   }, 
+	{ 102, i18n("ESE") },
+	{ 124, i18n("SE")  },
+	{ 147, i18n("SSE") },
+	{ 169, i18n("S")   },
+	{ 192, i18n("SSW") },
+	{ 214, i18n("SW")  },
+	{ 237, i18n("WSW") },
+	{ 259, i18n("W")   },
+	{ 282, i18n("WNW") },
+	{ 304, i18n("NW")  },
+	{ 327, i18n("NNW") },
+	{ 349, i18n("N")   },
+	{ 360, i18n("N")   }
+};
+
+
+QString WeatherLib::parseWindDirection(const unsigned int direction)
+{
+	unsigned int i = 0;
+	
+	for (i = 0; i < (sizeof(wind_direction) / sizeof(wind_info)) - 1; i++)
+	{
+		if (direction >= wind_direction[i].number &&
+		    direction < wind_direction[i + 1].number)
+		{
+			break;
+		}
+	}
+	
+	return wind_direction[i].name;
+}
+
 /** Parse the wind speed */
-bool WeatherLib::parseWindSpeed(QString s, Data *d)
+bool WeatherLib::parseWindSpeed(const QString &s, Data *d)
 {
 	if (WindRegExp.search(s) > -1)
 	{
-		int iDirection = WindRegExp.cap(1).toInt();
+		unsigned int direction = WindRegExp.cap(1).toInt();
 		int iWindSpeed = WindRegExp.cap(2).toInt();
 		int iGustSpeed = WindRegExp.cap(3).toInt();
 		QString sWindUnit = WindRegExp.cap(4);
 
-		kdDebug(12004) << "Wind: " << WindRegExp.capturedTexts().join("-")
+		kdDebug(12006) << "Wind: " << WindRegExp.capturedTexts().join("-")
 			<< endl;
 
 		if (KGlobal::locale()->measureSystem() == KLocale::Metric)
@@ -576,39 +615,7 @@ bool WeatherLib::parseWindSpeed(QString s, Data *d)
 
 		if ((WindRegExp.cap(1) != "VRB") && (iWindSpeed > 0))
 		{
-			if ((iDirection >=0 && iDirection <= 11)
-					|| ( iDirection >= 349 && iDirection <= 360))
-				d->qsWindDirection = i18n("N");
-			else if (iDirection >= 12 && iDirection <= 32)
-				d->qsWindDirection = i18n("NNE");
-			else if (iDirection >= 33 && iDirection <= 56)
-				d->qsWindDirection = i18n("NE");
-			else if (iDirection >= 57 && iDirection <= 78)
-				d->qsWindDirection = i18n("ENE");
-			else if (iDirection >= 79 && iDirection <= 101)
-				d->qsWindDirection = i18n("E");
-			else if (iDirection >= 102 && iDirection <= 123)
-				d->qsWindDirection = i18n("ESE");
-			else if (iDirection >= 124 && iDirection <= 146)
-				d->qsWindDirection = i18n("SE");
-			else if (iDirection >= 147 && iDirection <= 168)
-				d->qsWindDirection = i18n("SSE");
-			else if (iDirection >= 169 && iDirection <= 191)
-				d->qsWindDirection = i18n("S");
-			else if (iDirection >= 192 && iDirection <= 213)
-				d->qsWindDirection = i18n("SSW");
-			else if (iDirection >= 214 && iDirection <= 236)
-				d->qsWindDirection = i18n("SW");
-			else if (iDirection >= 237 && iDirection <= 258)
-				d->qsWindDirection = i18n("WSW");
-			else if (iDirection >= 259 && iDirection <= 281)
-				d->qsWindDirection = i18n("W");
-			else if (iDirection >= 282 && iDirection <= 303)
-				d->qsWindDirection = i18n("WNW");
-			else if (iDirection >= 304 && iDirection <= 326)
-				d->qsWindDirection = i18n("NW");
-			else if (iDirection >= 327 && iDirection <= 348)
-				d->qsWindDirection = i18n("NNW");
+			d->qsWindDirection = parseWindDirection(direction);
 		}
 		return true;
 	}
@@ -616,21 +623,22 @@ bool WeatherLib::parseWindSpeed(QString s, Data *d)
 }
 
 void WeatherLib::calcCurrentIcon(Data *d){
-       // Default to overcast clouds
-       if ( d->clouds == -1 )
-               d->clouds = 64;
+	// Default to overcast clouds
+	if ( d->clouds == -1 )
+		d->clouds = 64;
+
 	if (d->theWeather.isEmpty())
 	{
 		if (d->clouds == 0)
-			d->theWeather = "sunny";
+			d->theWeather = iconName("sunny", d);
 		else if (d->clouds > 0 && d->clouds <= 2)
-			d->theWeather = "cloudy1";
+			d->theWeather = iconName("cloudy1", d);
 		else if ( d->clouds > 2 && d->clouds <= 4)
-			d->theWeather = "cloudy2";
+			d->theWeather = iconName("cloudy2", d);
 		else if ( d->clouds > 4 && d->clouds <= 8)
-			d->theWeather = "cloudy3";
+			d->theWeather = iconName("cloudy3", d);
 		else if ( d->clouds > 8 && d->clouds < 63)
-			d->theWeather = "cloudy4";
+			d->theWeather = iconName( "cloudy4", d );
 		else
 			d->theWeather = "cloudy5";
 	}
@@ -640,9 +648,9 @@ void WeatherLib::calcCurrentIcon(Data *d){
 			d->clouds = 30;
 
 		if (d->clouds >= 0 && d->clouds <= 10)
-			d->theWeather = "tstorm1";
+			d->theWeather = iconName("tstorm1", d);
 		else if ( d->clouds > 10 && d->clouds <= 20)
-			d->theWeather = "tstorm2";
+			d->theWeather = iconName("tstorm2", d);
 		else
 			d->theWeather = "tstorm3";
 	}
@@ -652,9 +660,9 @@ void WeatherLib::calcCurrentIcon(Data *d){
 			d->clouds = 30;
 
 		if (d->clouds >= 0 && d->clouds <= 10)
-			d->theWeather = "shower1";
+			d->theWeather = iconName("shower1", d);
 		else if ( d->clouds > 10 && d->clouds <= 20)
-			d->theWeather = "shower2";
+			d->theWeather = iconName("shower2", d);
 		else
 			d->theWeather = "shower3";
 	}
@@ -664,16 +672,25 @@ void WeatherLib::calcCurrentIcon(Data *d){
 			d->clouds = 30;
 
 		if (d->clouds >= 0 && d->clouds <= 8)
-			d->theWeather = "snow1";
+			d->theWeather = iconName("snow1", d);
 		else if ( d->clouds > 8 && d->clouds <= 16)
-			d->theWeather = "snow2";
+			d->theWeather = iconName("snow2", d);
 		else if (d->clouds > 16 && d->clouds <= 24)
-			d->theWeather = "snow3";
+			d->theWeather = iconName("snow3", d);
 		else
 			d->theWeather = "snow5";
 	}
+	else if (isNight(d->reportLocation) && d->theWeather == "mist")
+		d->theWeather = "mist_night";
+	else if (isNight(d->reportLocation) && d->theWeather == "fog")
+                d->theWeather = "fog_night";
+	else if ( d->theWeather == "mist" || d->theWeather == "fog" )
+	{
+		if ( d->clouds >= 63 )
+			d->theWeather = "cloudy5";
+	}
 
-	kdDebug(12004) << "Clouds: " << d->clouds << ", Icon: "
+	kdDebug(12006) << "Clouds: " << d->clouds << ", Icon: "
 		<< d->theWeather << endl;
 }
 
@@ -682,7 +699,7 @@ void WeatherLib::calcWindChill(Data *d){
 		- (35.75*::pow(d->windMPH, 0.16))
 		+ (0.4275*d->tempF*::pow(d->windMPH, 0.16));
 
-	kdDebug(12004) << "Wind Chill: " << windChill << endl;
+	kdDebug(12006) << "Wind Chill: " << windChill << endl;
 
 	if (windChill < 48)
 	{
@@ -699,10 +716,10 @@ void WeatherLib::calcWindChill(Data *d){
 	}
 }
 
-void WeatherLib::processData(QString metar, Data *d){
-	d->clear();
+void WeatherLib::processData(const QString &metar, Data *d){
 
-	kdDebug(12004) << "Processing data: " << metar << endl;
+	d->clear();
+	kdDebug(12006) << "Processing data: " << metar << endl;
 
 	// Split at whitespace into tokens
 	QStringList dataList = QStringList::split(QRegExp("\\s+"), metar);
@@ -722,7 +739,7 @@ void WeatherLib::processData(QString metar, Data *d){
 			continue;
 		}
 
-		kdDebug(12004) << "Processing Token: " << *it << endl;
+		kdDebug(12006) << "Processing Token: " << *it << endl;
 		if (parseDate(*it, d))
 			continue;
 		if (parseTime(*it, d))
@@ -747,17 +764,16 @@ void WeatherLib::processData(QString metar, Data *d){
 
 void WeatherLib::slotCopyDone(KIO::Job* job)
 {
-	kdDebug(12004) << "Copy done..." << endl;
+	kdDebug(12006) << "Copy done..." << endl;
 	if( job->error())
 	{
-		kdDebug(12004) << "Error code: " << job->error() << endl;
+		kdDebug(12006) << "Error code: " << job->error() << endl;
 		//job->showErrorDialog(0L);
 		if(job->error() == KIO::ERR_COULD_NOT_CONNECT ||
 			job->error() == KIO::ERR_UNKNOWN_HOST)
 		{
 			hostDown= true;
 			// should not bother after this point
-			QPixmap pix();
 			KPassivePopup::message( i18n("KWeather Error!"),
 				i18n("The network is unavailable for use."),  0L,"error" );
 		}
@@ -767,78 +783,76 @@ void WeatherLib::slotCopyDone(KIO::Job* job)
 	Data *d = 0L;
 	for( ; it.current(); ++it )
 	{
-		kdDebug(12004) << "Searching for job..." << endl;
+		kdDebug(12006) << "Searching for job..." << endl;
 		if(it.current()->job == job)
 		{
-
 			d = it.current();
 			d->downloading = false;
 			if( !job->error() )
 			{
-				QFile f(d->target->name());
-				if ( f.open(IO_ReadOnly) )
+				kdDebug( 12006) << "Reading: " << d->target->name() << endl;
+				QFile file( d->target->name() );
+				file.open( IO_ReadOnly );
+				QTextStream *t = new QTextStream( &file );
+				//QTextStream *t = d->target->textStream();
+				if( t )
 				{
-					QTextStream t(&f);
-					QString s;
-					while ( !t.eof() )
+					QString s = QString::null;
+					while ( !t->eof() )
 					{
-						s += " " + t.readLine();
-						kdDebug( 12004 ) << s << endl;
+						s += " " + t->readLine();
+					}
+
+					if ( !s.isEmpty() )
+					{
+						kdDebug( 12006 ) << "Parse: " << s << endl;
+						processData(s, d);
+						d->age = QDateTime::currentDateTime().addSecs(1800);
+						emit fileUpdate(d->reportLocation);
+						d->updated = true;
+					}
+					else
+					{
+						// File error
+						kdDebug( 12006 ) << "File empty error..." << endl;
+						KPassivePopup::message( i18n("KWeather Error!"),
+						i18n("The temp file %1 was empty.").arg(d->target->name()),  0L,"error" );
+						d->updated = false;
 					}
-					processData(s, d);
-					d->age = QDateTime::currentDateTime().addSecs(3000);
-					emit  fileUpdate(QString(d->reportLocation));
-					d->updated = true;
 				}
 				else
 				{
 					// File error
-					kdDebug( 12004 ) << "File read error..." << endl;
+					kdDebug( 12006 ) << "File read error..." << endl;
 					KPassivePopup::message( i18n("KWeather Error!"),
-				i18n("Could not read the temp file."),  0L,"error" );
+				i18n("Could not read the temp file %1.").arg(d->target->name()),  0L,"error" );
 					d->updated = false;
 				}
-				f.close();
 				delete d->target;
+				d->target = 0L;
+				d->job = 0L;
 
 			}
 			else if( job->error()  == KIO::ERR_DOES_NOT_EXIST)
 			{
 				data.remove(d->reportLocation);
-				kdDebug( 12004 ) << "Bad station data so i am going to remove it" << endl;
+				kdDebug( 12006 ) << "Bad station data so i am going to remove it" << endl;
 				KPassivePopup::message( i18n("KWeather Error!"),
 				i18n("The requested station does not exist."),  0L,"error" );
 			}
 			else if(job->error() == KIO::ERR_COULD_NOT_CONNECT ||
 				job->error() == KIO::ERR_UNKNOWN_HOST)
 			{
-				kdDebug( 12004 ) << "Offline now..." << endl;
-				d->updated = false;
+				kdDebug( 12006 ) << "Offline now..." << endl;
+				d->clear();
 				d->theWeather = "dunno";
-				d->clouds = 0;
-				d->windMPH = 0;
-				d->tempF = 0;
-				d->qsCoverList.clear();
-				d->qsCurrentList.clear();
 				d->qsCurrentList.append(i18n("The network is currently offline..."));
 				d->qsCurrentList.append(i18n("Please update later."));
-				d->qsDate = QDate::currentDate();
-				d->qsPressure = "XX";
-				d->qsTemperature = "XX";
-				d->qsDewPoint = "XX";
-				d->qsRelHumidity = "XX";
-				d->qsTime = QTime::currentTime();
-				d->qsVisibility = "XX";
-				d->qsWindSpeed = "XX";
-				d->qsWindChill = "XX";
-				d->qsHeatIndex = "XX";
-				d->qsWindDirection = "XX";
-				emit  fileUpdate(QString(d->reportLocation));
-				delete d->target;
+				emit fileUpdate(d->reportLocation);
 			}
 			else
 			{
-				kdDebug( 12004 ) << "Duh?..." << endl;
+				kdDebug( 12006 ) << "Duh?..." << endl;
 			}
 
 		}
@@ -849,6 +863,7 @@ void WeatherLib::getData(Data *d)
 {
 	if(!d->downloading && !hostDown)
 	{
+		d->downloading = true;
 		d->updated = false;
 		QString u = "http://weather.noaa.gov/pub/data/observations/metar/stations/";
 		u += d->reportLocation.upper().stripWhiteSpace();
@@ -856,82 +871,79 @@ void WeatherLib::getData(Data *d)
 
 		d->target = new KTempFile(QString::null, "-weather");
 		d->target->setAutoDelete(true);
+		d->target->file();
+
 		KURL url(u);
 		KURL local(d->target->name());
 
 		d->job = KIO::file_copy( url, local, -1, true, false, false);
+		d->job->addMetaData("cache", "reload"); // Make sure to get fresh info
 		connect( d->job, SIGNAL( result( KIO::Job *)),
 			SLOT(slotCopyDone(KIO::Job *)));
-		d->downloading = true;
-		kdDebug( 12004 ) << "Copying " << url.prettyURL() << " to "
+		kdDebug( 12006 ) << "Copying " << url.prettyURL() << " to "
 			<< local.prettyURL() << endl;
-		emit fileUpdateing(QString(d->reportLocation));
+		emit fileUpdating(d->reportLocation);
 	}
 }
 
-WeatherLib::Data* WeatherLib::findData(QString stationID)
+WeatherLib::Data* WeatherLib::findData(const QString &stationID)
 {
 	Data *d = data[stationID];
 	if (!d)
 	{
 		d = new Data();
 		d->reportLocation = stationID;
+		d->theWeather = "dunno";
+		d->qsCurrentList.append( i18n( "Retrieving weather data..." ) );
 		data.insert(stationID, d);
 		getData(d);
-/*		while(!d->updated && !hostDown)
-		{
-			usleep(250);
-			//kdDebug( 12004 ) << "spin..." << endl;
-			kapp->processEvents();
-		}
-*/
 	}
 
 	return d;
 }
 
-QString WeatherLib::temperature(QString stationID){
+QString WeatherLib::temperature(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsTemperature;
 }
 
-QString WeatherLib::pressure(QString stationID){
+QString WeatherLib::pressure(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsPressure;
 }
 
-QString WeatherLib::wind(QString stationID){
+QString WeatherLib::wind(const QString &stationID){
 	Data *d = findData(stationID);
 	return (d->qsWindSpeed + " " + d->qsWindDirection);
 }
 
 /**  */
-QString WeatherLib::dewPoint(QString stationID){
+QString WeatherLib::dewPoint(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsDewPoint;
 }
 
-QString WeatherLib::relHumidity(QString stationID){
+QString WeatherLib::relHumidity(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsRelHumidity;
 }
 
-QString WeatherLib::heatIndex(QString stationID){
+QString WeatherLib::heatIndex(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsHeatIndex;
 }
 
-QString WeatherLib::windChill(QString stationID){
+QString WeatherLib::windChill(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsWindChill;
 }
 
-QString WeatherLib::currentIcon(QString stationID){
+QString WeatherLib::iconName(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->theWeather;
 }
 
-QString WeatherLib::date(QString stationID){
+QString WeatherLib::date(const QString &stationID){
 	Data *d = findData(stationID);
 
 	QDateTime gmtDateTime(d->qsDate, d->qsTime);
@@ -940,24 +952,24 @@ QString WeatherLib::date(QString stationID){
 }
 
 /** Returns the current cover */
-QStringList WeatherLib::cover(QString stationID){
+QStringList WeatherLib::cover(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsCoverList;
 }
 
 /** return the visibility */
-QString WeatherLib::visibility(QString stationID){
+QString WeatherLib::visibility(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsVisibility;
 }
 
 /** return the weather text */
-QStringList WeatherLib::weather(QString stationID){
+QStringList WeatherLib::weather(const QString &stationID){
 	Data *d = findData(stationID);
 	return d->qsCurrentList;
 }
 
-void WeatherLib::update(QString stationID)
+void WeatherLib::update(const QString &stationID)
 {
 	// refresh hostdown just to see
 	hostDown = false;
@@ -966,13 +978,12 @@ void WeatherLib::update(QString stationID)
 
 	QDateTime timeout = QDateTime::currentDateTime();
 
-	kdDebug () << "Current Time: " << KGlobal::locale()->formatDateTime(timeout, false, false) <<
+	kdDebug (12006) << "Current Time: " << KGlobal::locale()->formatDateTime(timeout, false, false) <<
 			" Update at: " << KGlobal::locale()->formatDateTime(d->age, false, false) << endl;
 	if( timeout >= d->age || !d->updated)
 		getData(d);
 	else
-		 emit  fileUpdate(QString(d->reportLocation));
-
+		emit fileUpdate(d->reportLocation);
 }
 
 QStringList WeatherLib::stations()
@@ -984,28 +995,42 @@ QStringList WeatherLib::stations()
 	return l;
 }
 
-void WeatherLib::blockingUpdate(QString stationID)
+void WeatherLib::forceUpdate(const QString &stationID)
 {
-	// Only grab new data if its more than 50 minutes old
 	Data *d = findData(stationID);
 
-	QDateTime timeout = QDateTime::currentDateTime();
-
-	kdDebug () << "Current Time: " << KGlobal::locale()->formatDateTime(timeout, false, false) <<
-			" Update at: " << KGlobal::locale()->formatDateTime(d->age, false, false) << endl;
-	int giveup = 0;
-	if( timeout >= d->age)
-		getData(d);
-	while(!d->updated && !hostDown && giveup < 140) // Timeout after 30 seconds...
-	{
-		usleep(250);
-		//kdDebug( 12004 ) << "spin..." << endl;
-		kapp->processEvents();
-		++giveup;
-	}
+	getData( d );
 }
 
-void WeatherLib::remove(QString stationID)
+void WeatherLib::remove(const QString &stationID)
 {
 	data.remove(stationID);
+  emit stationRemoved(stationID);
 }
+
+bool WeatherLib::isNight(const QString &stationID) const
+{
+	Sun theSun;
+	QString latitude  = m_StationDb->stationLatitudeFromID(stationID);
+	QString longitude = m_StationDb->stationLongitudeFromID(stationID);
+
+	QTime currently = QTime::currentTime();
+
+	QTime rise_time = theSun.computeRiseTime(latitude, longitude);
+	QTime set_time  = theSun.computeSetTime(latitude, longitude);
+
+	//kdDebug (12006) << "current, rise, set: " << currently << " " << rise_time << " " << set_time << endl;
+	
+	return (currently < rise_time || currently > set_time);
+}
+
+QString WeatherLib::iconName( const QString &icon, Data *d ) const
+{
+	QString _iconName = icon;
+
+	if ( isNight( d->reportLocation ) )
+		_iconName += "_night";
+
+    return _iconName;
+}
+
