@@ -5,7 +5,10 @@ TEMP=`dcop KWeatherService WeatherService temperature $LOC`
 WIND=`dcop KWeatherService WeatherService wind $LOC`
 DATE=`dcop KWeatherService WeatherService date $LOC`
 VIS=`dcop KWeatherService WeatherService visability $LOC`
+NAME=`dcop KWeatherService WeatherService stationName $LOC`
+EMAIL="geiseri@kde.org"
 echo "===+<KWeather for KDE 3.1>+=+<http://www.kde.org>+==="
-echo "   Report for $DATE"
-echo "   $TEMP with winds at $WIND and $VIS of visability."
-echo "===============================+<geiseri@kde.org>+==="
+echo "   Report for $NAME" 
+echo "		on $DATE"
+echo "   $TEMP with winds at $WIND and $VIS of visibility."
+echo "===============================+<$EMAIL>+==="
