@@ -1,3 +1,30 @@
+/*
+**
+** Copyright (C) 1998-2001 by Matthias Hlzer-Klpfel <hoelzer@kde.org>
+**	Maintainence has ceased - send questions to kde-devel@kde.org.
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 #include <limits.h>
 
 
@@ -81,6 +108,10 @@ void FlagList::removeNearestFlag(QPoint target, int w, int h, int offset)
     _flags.remove(flag);
 }
 
+void FlagList::removeAllFlags()
+{
+  _flags.clear();
+}
 
 void FlagList::save(KConfig *config)
 {
