@@ -1,3 +1,30 @@
+/*
+**
+** Copyright (C) 1998-2001 by Matthias Hlzer-Klpfel <hoelzer@kde.org>
+**	Maintainence has ceased - send questions to kde-devel@kde.org.
+**
+*/
+
+/*
+** This program is free software; you can redistribute it and/or modify
+** it under the terms of the GNU General Public License as published by
+** the Free Software Foundation; either version 2 of the License, or
+** (at your option) any later version.
+**
+** This program is distributed in the hope that it will be useful,
+** but WITHOUT ANY WARRANTY; without even the implied warranty of
+** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
+** GNU General Public License for more details.
+**
+** You should have received a copy of the GNU General Public License
+** along with this program in a file called COPYING; if not, write to
+** the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
+** MA 02111-1307, USA.
+*/
+
+/*
+** Bug reports and questions can be sent to kde-devel@kde.org
+*/
 #include <stdlib.h>
 
 
@@ -28,7 +55,7 @@ WorldWideWatch::WorldWideWatch(bool restore, QWidget *parent, const char *name)
   QWidget *w = new QWidget(this);
   setCentralWidget(w);
 
-  setPlainCaption(i18n("The KDE World Clock"));
+  setPlainCaption(i18n("KDE World Clock"));
   
   QVBoxLayout *vbox = new QVBoxLayout(w, 0,0);
   
@@ -105,16 +132,23 @@ void WatchApplication::dumpMap()
 
 int WatchApplication::newInstance()
 {
+  static bool first = true;
+
   // dump mode, used for background drawing
   KCmdLineArgs *args = KCmdLineArgs::parsedArgs();
   if (args->isSet("dump"))
     {
       dumpMap();
+      first = false;
       return 0;
     }
 
-  WorldWideWatch *www = new WorldWideWatch(true);
-  www->show();
+  if (!isRestored() || !first)
+  {
+    WorldWideWatch *www = new WorldWideWatch(true);
+    www->show();
+  }
+  first = false;
 
   return 0;
 }
@@ -126,7 +160,7 @@ static KCmdLineOptions options[] =
   { "theme <file>", I18N_NOOP("The name of the theme to use for --dump"), "earth"},
   { "o <file>", I18N_NOOP("The name of the file to write to"), "dump.ppm" },
   { "size <WxH>", I18N_NOOP("The size of the map to dump"), 0 },
-  { 0, 0, 0 }
+  KCmdLineLastOption
 };
 
 
